pub struct MissingContextError<'c> {
span: Span,
error_handler: &'c (dyn Fn(Span) -> Error + 'c),
}Expand description
Cheap type that embodies a failed requirement for a driver
This can be pre-obtained and bound to a local ctx, and then
converted conveniently to syn::Error with ctx? when actually
needed.
Fields
span: Spanerror_handler: &'c (dyn Fn(Span) -> Error + 'c)Trait Implementations
Sourceimpl<'c> Clone for MissingContextError<'c>
impl<'c> Clone for MissingContextError<'c>
Sourcefn clone(&self) -> MissingContextError<'c>
fn clone(&self) -> MissingContextError<'c>
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl<'c> From<MissingContextError<'c>> for Error
impl<'c> From<MissingContextError<'c>> for Error
Sourcefn from(e: MissingContextError<'c>) -> Error
fn from(e: MissingContextError<'c>) -> Error
Converts to this type from the input type.
impl<'c> Copy for MissingContextError<'c>